Welcome to the ``calibr8`` documentation!
=========================================

.. image:: https://img.shields.io/badge/code%20on-Github-lightgrey
    :target: https://github.com/michaelosthege/calibr8

.. image:: https://zenodo.org/badge/306862348.svg
   :target: https://zenodo.org/badge/latestdoi/306862348

With ``calibr8`` we take a fresh perspective on calibration modeling.

You can download the latest version from `GitHub <https://github.com/michaelosthege/calibr8>`_ or install it via ``pip install calibr8``.

In the following chapters, we introduce the terminology, basic concepts and most important features.

.. toctree::
   :maxdepth: 2
   :numbered:
   :caption: Contents

   01_terminology
   02_fitting
   03_features

Learn from the examples how a ``calibr8``-driven workflow looks like:

.. toctree::
   :maxdepth: 2
   :caption: Examples

   Example_Fitting_a_Linear_Model
   Example_Numeric_Independent_Posterior
   Advanced_In-depth_Model_Fitting
   Advanced_Custom_Noise_Models
   Advanced_Hierarchical_Calibration


You can find autogenerated API documentation below:

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   calibr8_inheritance.md
   calibr8_core
   calibr8_contrib_base
   calibr8_optimization
   calibr8_utils
